You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tamaya.apache.org by pl...@apache.org on 2016/09/25 21:23:58 UTC

[10/50] [abbrv] incubator-tamaya-sandbox git commit: Moved PropertyConverter into SPI package.

Moved PropertyConverter into SPI package.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/commit/1a7b54d3
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/tree/1a7b54d3
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/diff/1a7b54d3

Branch: refs/heads/master
Commit: 1a7b54d34f01cb40e25d939f2ce44fadf8c6ef66
Parents: a63c28f
Author: anatole <an...@apache.org>
Authored: Fri Apr 17 22:41:11 2015 +0200
Committer: anatole <an...@apache.org>
Committed: Fri Apr 17 22:41:11 2015 +0200

----------------------------------------------------------------------
 .../tamaya/builder/ConfigurationBuilder.java    | 20 ++++++++++----------
 .../ProgrammaticConfigurationContext.java       |  4 ++--
 .../types/CustomTypeCPropertyConverter.java     |  2 +-
 .../org.apache.tamaya.PropertyConverter         | 19 -------------------
 .../org.apache.tamaya.spi.PropertyConverter     | 19 +++++++++++++++++++
 5 files changed, 32 insertions(+), 32 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/1a7b54d3/src/main/java/org/apache/tamaya/builder/ConfigurationBuilder.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/tamaya/builder/util/types/CustomTypeCPropertyConverter.java b/src/test/java/org/apache/tamaya/builder/util/types/CustomTypeCPropertyConverter.java
index 1754b30..c7d1490 100644
--- a/src/test/java/org/apache/tamaya/builder/util/types/CustomTypeCPropertyConverter.java
+++ b/src/test/java/org/apache/tamaya/builder/util/types/CustomTypeCPropertyConverter.java
@@ -18,7 +18,7 @@
  */
 package org.apache.tamaya.builder.util.types;
 
-import org.apache.tamaya.PropertyConverter;
+import org.apache.tamaya.spi.PropertyConverter;
 
 public class CustomTypeCPropertyConverter implements PropertyConverter<org.apache.tamaya.builder.util.types.CustomTypeC> {
     @Override

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/1a7b54d3/src/test/resources/META-INF/services/org.apache.tamaya.PropertyConverter
----------------------------------------------------------------------
diff --git a/src/test/resources/META-INF/services/org.apache.tamaya.PropertyConverter b/src/test/resources/META-INF/services/org.apache.tamaya.PropertyConverter
deleted file mode 100644
index b9e0d44..0000000
--- a/src/test/resources/META-INF/services/org.apache.tamaya.PropertyConverter
+++ /dev/null
@@ -1,19 +0,0 @@
-#
-# Licensed to the Apache Software Foundation (ASF) under one
-# or more contributor license agreements.  See the NOTICE file
-# distributed with this work for additional information
-# regarding copyright ownership.  The ASF licenses this file
-# to you under the Apache License, Version 2.0 (the
-# "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy current the License at
-#
-#    http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing,
-# software distributed under the License is distributed on an
-# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-# KIND, either express or implied.  See the License for the
-# specific language governing permissions and limitations
-# under the License.
-#
-org.apache.tamaya.builder.util.types.CustomTypeCPropertyConverter
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/1a7b54d3/src/test/resources/META-INF/services/org.apache.tamaya.spi.PropertyConverter
----------------------------------------------------------------------
diff --git a/src/test/resources/META-INF/services/org.apache.tamaya.spi.PropertyConverter b/src/test/resources/META-INF/services/org.apache.tamaya.spi.PropertyConverter
new file mode 100644
index 0000000..b9e0d44
--- /dev/null
+++ b/src/test/resources/META-INF/services/org.apache.tamaya.spi.PropertyConverter
@@ -0,0 +1,19 @@
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy current the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+#
+org.apache.tamaya.builder.util.types.CustomTypeCPropertyConverter
\ No newline at end of file
diff --git a/src/main/java/org/apache/tamaya/builder/ConfigurationBuilder.java b/src/main/java/org/apache/tamaya/builder/ConfigurationBuilder.java
index 21d6cf7..dfe821b 100644
--- a/src/main/java/org/apache/tamaya/builder/ConfigurationBuilder.java
+++ b/src/main/java/org/apache/tamaya/builder/ConfigurationBuilder.java
@@ -20,7 +20,7 @@ package org.apache.tamaya.builder;
 
 import org.apache.tamaya.ConfigException;
 import org.apache.tamaya.Configuration;
-import org.apache.tamaya.PropertyConverter;
+import org.apache.tamaya.spi.PropertyConverter;
 import org.apache.tamaya.TypeLiteral;
 import org.apache.tamaya.core.internal.DefaultConfiguration;
 import org.apache.tamaya.format.ConfigurationData;
@@ -326,7 +326,7 @@ public class ConfigurationBuilder {
      *
      * @return the builder instance currently used
      *
-     * @see org.apache.tamaya.PropertyConverter
+     * @see org.apache.tamaya.spi.PropertyConverter
      * @see #enableProvidedPropertyConverters()
      * @see #disableProvidedPropertyConverters()
      */
@@ -349,7 +349,7 @@ public class ConfigurationBuilder {
     }
 
     /**
      * Checks if the automatic loading of all {@link org.apache.tamaya.PropertyConverter
      * PropertyConverter} service providers is enabled or disabled.
      *
      * @return {@code true} if the automatic loading is enabled,
@@ -357,20 +357,20 @@ public class ConfigurationBuilder {
      *
      * @see #enableProvidedPropertyConverters()
      * @see #disableProvidedPropertyConverters()
-     * @see #addPropertyConverter(Class, org.apache.tamaya.PropertyConverter)
-     * @see #addPropertyConverter(org.apache.tamaya.TypeLiteral, org.apache.tamaya.PropertyConverter)
+     * @see #addPropertyConverter(Class, org.apache.tamaya.spi.PropertyConverter)
+     * @see #addPropertyConverter(org.apache.tamaya.TypeLiteral, org.apache.tamaya.spi.PropertyConverter)
      */
     public boolean isPropertyConverterLoadingEnabled() {
         return loadProvidedPropertyConverters;
     }
 
     /**
-     * Enables the loading of all {@link org.apache.tamaya.PropertyConverter}
+     * Enables the loading of all {@link org.apache.tamaya.spi.PropertyConverter}
      * service providers.
      *
      * @return the builder instance currently used
      *
-     * @see org.apache.tamaya.PropertyConverter
+     * @see org.apache.tamaya.spi.PropertyConverter
      * @see #disableProvidedPropertyConverters()
      * @see #enableProvidedPropertyConverters()
      */
@@ -383,14 +383,14 @@ public class ConfigurationBuilder {
     }
 
     /**
-     * Disables the automatic loading of all {@link org.apache.tamaya.PropertyConverter}
+     * Disables the automatic loading of all {@link org.apache.tamaya.spi.PropertyConverter}
      * service providers.
      *
      * @return the builder instance currently used
      *
-     * @see org.apache.tamaya.PropertyConverter
+     * @see org.apache.tamaya.spi.PropertyConverter
      * @see #enableProvidedPropertyConverters()
-     * @see #addPropertyConverter(Class, org.apache.tamaya.PropertyConverter)
+     * @see #addPropertyConverter(Class, org.apache.tamaya.spi.PropertyConverter)
      */
     public ConfigurationBuilder disableProvidedPropertyConverters() {
         checkBuilderState();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/1a7b54d3/src/main/java/org/apache/tamaya/builder/ProgrammaticConfigurationContext.java
----------------------------------------------------------------------
@@ -349,7 +349,7 @@ public class ConfigurationBuilder {
 
     /**
-     * Checks if the automatic loading of all {@link org.apache.tamaya.PropertyConverter
+     * Checks if the automatic loading of all {@link org.apache.tamaya.spi.PropertyConverter
      * PropertyConverter} service providers is enabled or disabled.
      *
diff --git a/src/main/java/org/apache/tamaya/builder/ProgrammaticConfigurationContext.java b/src/main/java/org/apache/tamaya/builder/ProgrammaticConfigurationContext.java
index 6c7e845..d867c3e 100644
--- a/src/main/java/org/apache/tamaya/builder/ProgrammaticConfigurationContext.java
+++ b/src/main/java/org/apache/tamaya/builder/ProgrammaticConfigurationContext.java
@@ -19,7 +19,7 @@
 package org.apache.tamaya.builder;
 
 
-import org.apache.tamaya.PropertyConverter;
+import org.apache.tamaya.spi.PropertyConverter;
 import org.apache.tamaya.TypeLiteral;
 import org.apache.tamaya.core.internal.PropertyConverterManager;
 import org.apache.tamaya.spi.ConfigurationContext;
@@ -62,7 +62,7 @@ class ProgrammaticConfigurationContext implements ConfigurationContext {
      */
     private final static Logger LOG = Logger.getLogger(ProgrammaticConfigurationContext.class.getName());
     /**
      * Cubcomponent handling {@link org.apache.tamaya.PropertyConverter} instances.
      */
     private PropertyConverterManager propertyConverterManager = new PropertyConverterManager();
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/1a7b54d3/src/test/java/org/apache/tamaya/builder/util/types/CustomTypeCPropertyConverter.java
----------------------------------------------------------------------
@@ -62,7 +62,7 @@ class ProgrammaticConfigurationContext implements ConfigurationContext {
     private final static Logger LOG = Logger.getLogger(ProgrammaticConfigurationContext.class.getName());
     /**
-     * Cubcomponent handling {@link org.apache.tamaya.PropertyConverter} instances.
+     * Cubcomponent handling {@link org.apache.tamaya.spi.PropertyConverter} instances.
      */
     private PropertyConverterManager propertyConverterManager = new PropertyConverterManager();